@@ -24,5 +24,7 @@ class SSHGrainsTest(SSHCase):
         grain = 'Linux'
         if salt.utils.platform.is_darwin():
             grain = 'Darwin'
+        if salt.utils.platform.is_aix():
+            grain = 'AIX'
         self.assertEqual(ret['kernel'], grain)
         self.assertTrue(isinstance(ret, dict))
