@@ -8,13 +8,11 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 # Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
-from tests.support.unit import TestCase, skipIf
+from tests.support.unit import TestCase
 from tests.support.mock import (
     MagicMock,
     patch,
     mock_open,
-    NO_MOCK,
-    NO_MOCK_REASON
 )
 
 # Import Salt Libs
@@ -23,7 +21,6 @@ from salt.ext.six.moves.urllib.error import URLError  # pylint: disable=import-e
 from salt.utils.odict import OrderedDict
 
 
-@skipIf(NO_MOCK, NO_MOCK_REASON)
 class ApacheTestCase(TestCase, LoaderModuleMockMixin):
     '''
     Test cases for salt.modules.apache
